@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver_types.h,v 1.48 2006/12/26 13:13:24 hoa Exp $
+ * $Id: maildriver_types.h,v 1.49 2008/04/19 09:25:40 hoa Exp $
  */
 
 #ifndef MAILDRIVER_TYPES_H
@@ -747,23 +747,23 @@ struct mailmessage {
 /*
   mailmessage_tree is a node in the messages tree (thread)
   
-  - parent is the parent of the message, it is NULL if the message
+  - node_parent is the parent of the message, it is NULL if the message
       is the root of the message tree.
 
-  - date is the date of the message in number of second elapsed
+  - node_msgid is the message ID of this node.
+
+  - node_date is the date of the message in number of second elapsed
       since 00:00:00 on January 1, 1970, Coordinated Universal Time (UTC).
 
-  - msg is the message structure that is stored referenced by the node.
+  - node_msg is the message structure that is stored referenced by the node.
       is msg is NULL, this is a dummy node.
 
-  - children is an array that contains all the children of the node.
+  - node_children is an array that contains all the children of the node.
       children are mailmessage_tree structures.
 
-  - is_reply is != 0 when the message is a reply or a forward
+  - node_is_reply is != 0 when the message is a reply or a forward
 
-  - base_subject is the extracted subject of the message.
-
-  - index is the message number.
+  - node_base_subject is the extracted subject of the message.
 */
 
 struct mailmessage_tree {
