@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_decode.h,v 1.13 2005/06/01 12:22:19 smarinier Exp $
+ * $Id: mailmime_decode.h,v 1.14 2008/02/20 22:15:52 hoa Exp $
  */
 
 #ifndef MAILMIME_DECODE_H
@@ -46,9 +46,15 @@ extern "C" {
 LIBETPAN_EXPORT
 int mailmime_encoded_phrase_parse(const char * default_fromcode,
     const char * message, size_t length,
-    size_t * index, const char * tocode,
+    size_t * indx, const char * tocode,
     char ** result);
 
+int
+mailmime_encoded_word_parse(const char * message, size_t length,
+                            size_t * indx,
+                            struct mailmime_encoded_word ** result,
+                            int * p_has_fwd, int * p_missing_closing_quote);
+
 #ifdef __cplusplus
 }
 #endif
