@@ -62,9 +62,12 @@ enum {
   MAILPOP3_ERROR_APOP_NOT_SUPPORTED,
   MAILPOP3_ERROR_CAPA_NOT_SUPPORTED,
   MAILPOP3_ERROR_STLS_NOT_SUPPORTED,
-  MAILPOP3_ERROR_SSL
+  MAILPOP3_ERROR_SSL,
+  MAILPOP3_ERROR_QUIT_FAILED
 };
 
+typedef struct mailpop3 mailpop3;
+
 struct mailpop3
 {
   char * pop3_response;               /* response message */
@@ -92,9 +95,14 @@ struct mailpop3
     const char * sasl_realm;
     void * sasl_secret;
   } pop3_sasl;
-};
 
-typedef struct mailpop3 mailpop3;
+  time_t pop3_timeout;
+  mailprogress_function * pop3_progress_fun;
+  void * pop3_progress_context;
+  
+  void (* pop3_logger)(mailpop3 * session, int log_type, const char * str, size_t size, void * context);
+  void * pop3_logger_context;
+};
 
 struct mailpop3_msg_info
 {
@@ -110,6 +118,12 @@ struct mailpop3_capa {
   clist * cap_param; /* (char *) */
 };
 
+
+struct mailpop3_stat_response  {
+  unsigned int msgs_count;
+  size_t msgs_size;
+};
+
 #ifdef __cplusplus
 }
 #endif
